#include "dialog.h"
#include "ui_dialog.h"
#include "version.h"
#include <QDebug>
#include <QSettings>

quint16 SPEED_MIN=10;
quint16 SPEED_MAX=220;

Dialog::Dialog(QWidget *parent)
    : QDialog(parent), ui(new Ui::Dialog)
    ,bpm(80)
    ,beats(4)
    ,started(false)
{
    QSettings settings;
    bpm=settings.value("bpm",80).toInt();
    
    ui->setupUi(this);
    
    QString title;
    title.append(tr("This QT metronome is free !\n"));
    title.append(tr("It is compatible with (designed for) pulseaudio.\nBy Stephane List\n"));
    title.append(tr("Version qMetronome : "));
    title.append(VERSION);
    title.append(tr("\nVersion Pulse Audio : "));
    title.append(pan.get_library_version());
    ui->label_title->setText(title);
    fix_speed(bpm);
    connect(&timer, SIGNAL(timeout()), this, SLOT(tick()));
}

Dialog::~Dialog()
{
    QSettings settings;
    settings.setValue("bpm",bpm);
    
    delete ui;
}

void Dialog::fix_speed(quint16 s)
{
    bpm=qBound(SPEED_MIN, s, SPEED_MAX);
    update_speed_label();
    ui->horizontalSlider_speed->setValue(s);
    timer.setInterval(60*1000/bpm);
}

void Dialog::adjust_speed(qint16 s)
{
    fix_speed(bpm+s);
    qDebug() << "bpm=" << bpm;
}

void Dialog::update_speed_label()
{
    QString str = QString(tr("%1 Beats Per Minute\n")).arg(bpm, 0, 10);
    if (bpm <= 20)
        str += "Larghissimo";
    else if (bpm <= 40)
        str += "Largamente";
    else if (bpm <= 60)
        str += "Largo";
    else if (bpm <= 66)
        str += "Larghetto";
    else if (bpm <= 76)
        str += "Adagio";
    else if (bpm <= 80)
        str += "Adagietto";
    else if (bpm <= 108)
        str += "Andante";
    else if (bpm <= 120)
        str += "Moderato";
    else if (bpm <= 168)
        str += "Allegro";
    else if (bpm <= 200)
        str += "Presto";
    else
        str += "Prestissimo";
    
    ui->label_speed->setText(str);
}

void Dialog::on_pushButton_p10_clicked()
{
    adjust_speed(10);
}

void Dialog::on_pushButton_p1_clicked()
{
    adjust_speed(1);
}

void Dialog::on_pushButton_m10_clicked()
{
    adjust_speed(-10);
}

void Dialog::on_pushButton_m1_clicked()
{
    adjust_speed(-1);
}
void Dialog::on_horizontalSlider_speed_valueChanged(int v)
{
    fix_speed(v);
}

void Dialog::on_pushButton_start_clicked()
{
    if (started)
    {
        ui->pushButton_start->setText(tr("Start"));
        started=false;
        timer.stop();
    }
    else
    {
        ui->pushButton_start->setText(tr("Stop"));
        started=true;
        timer.start();
    }
}

void Dialog::tick()
{
    int i;
    pan.play();
    i = ui->lcdNumber->intValue();
    ui->lcdNumber->display((++i %2));
}
